summaryrefslogtreecommitdiffstats
path: root/android_webview/native
diff options
context:
space:
mode:
authorapavlov <apavlov@chromium.org>2015-02-06 06:35:27 -0800
committerCommit bot <commit-bot@chromium.org>2015-02-06 14:36:25 +0000
commitadb1d7096d2c2da9a5843edc718378663587ef91 (patch)
treec530167fd12704c361c4f8791980980278b45a2e /android_webview/native
parent4708c92fc90880c25012b87188831b224be6adb3 (diff)
downloadchromium_src-adb1d7096d2c2da9a5843edc718378663587ef91.zip
chromium_src-adb1d7096d2c2da9a5843edc718378663587ef91.tar.gz
chromium_src-adb1d7096d2c2da9a5843edc718378663587ef91.tar.bz2
Revert "Adding q=low to the Chrome-Proxy request header"
Speculatively revert https://codereview.chromium.org/791493015 due to multiple browser_tests failures (e.g. see https://build.chromium.org/p/chromium.webkit/builders/Win7%20%28dbg%29/builds/15751) They are all due to SystemURLRequestContextGetter-related leaks. This reverts commit 8fbff4fad29b9e2408c634e178386d456acf6467. TBR=megjablon NOPRESUBMIT=true NOTREECHECKS=true NOTRY=true BUG=456110 Review URL: https://codereview.chromium.org/903073003 Cr-Commit-Position: refs/heads/master@{#315031}
Diffstat (limited to 'android_webview/native')
-rw-r--r--android_webview/native/aw_contents_statics.cc7
1 files changed, 4 insertions, 3 deletions
diff --git a/android_webview/native/aw_contents_statics.cc b/android_webview/native/aw_contents_statics.cc
index 77747e1..e09fcb8c 100644
--- a/android_webview/native/aw_contents_statics.cc
+++ b/android_webview/native/aw_contents_statics.cc
@@ -10,7 +10,7 @@
#include "base/android/jni_string.h"
#include "base/android/scoped_java_ref.h"
#include "base/callback.h"
-#include "components/data_reduction_proxy/core/browser/data_reduction_proxy_request_options.h"
+#include "components/data_reduction_proxy/core/browser/data_reduction_proxy_auth_request_handler.h"
#include "content/public/browser/android/synchronous_compositor.h"
#include "content/public/browser/browser_thread.h"
#include "content/public/common/url_constants.h"
@@ -21,6 +21,7 @@ using base::android::AttachCurrentThread;
using base::android::ConvertJavaStringToUTF8;
using base::android::ScopedJavaGlobalRef;
using content::BrowserThread;
+using data_reduction_proxy::DataReductionProxyAuthRequestHandler;
namespace android_webview {
@@ -59,13 +60,13 @@ void SetDataReductionProxyKey(JNIEnv* env, jclass, jstring key) {
// The following call to GetRequestContext() could possibly be the first such
// call, which means AwURLRequestContextGetter::InitializeURLRequestContext
// will be called on IO thread as a result. InitializeURLRequestContext()
// will initialize DataReductionProxyRequestOptions.
AwURLRequestContextGetter* aw_url_request_context_getter =
static_cast<AwURLRequestContextGetter*>(
browser_context->GetRequestContext());
// This PostTask has to be called after GetRequestContext, because SetKeyOnIO
// needs a valid DataReductionProxyRequestOptions object.
BrowserThread::PostTask(BrowserThread::IO,
FROM_HERE,
base::Bind(&AwURLRequestContextGetter::SetKeyOnIO,
@@ -59,13 +60,13 @@ void SetDataReductionProxyKey(JNIEnv* env, jclass, jstring key) {
// call, which means AwURLRequestContextGetter::InitializeURLRequestContext
// will be called on IO thread as a result. InitializeURLRequestContext()
- // will initialize DataReductionProxyRequestOptions.
+ // will initialize DataReductionProxyAuthRequestHandler.
AwURLRequestContextGetter* aw_url_request_context_getter =
static_cast<AwURLRequestContextGetter*>(
@@ -59,13 +60,13 @@ void SetDataReductionProxyKey(JNIEnv* env, jclass, jstring key) {
browser_context->GetRequestContext());
// This PostTask has to be called after GetRequestContext, because SetKeyOnIO
- // needs a valid DataReductionProxyRequestOptions object.
+ // needs a valid DataReductionProxyAuthRequestHandler object.
BrowserThread::PostTask(BrowserThread::IO,
FROM_HERE,